@@ -24,4 +24,4 @@ class MotorcycleModel(CamelModel):
     power_supply: Optional[List[PowerSupplyComponent]]
     distribution: Optional[DistributionData]
     autodiagnosis: Optional[AutodiagnosisData]
-    absData: Optional[AbsData]
+    abs_data: Optional[AbsData]
