@@ -67,7 +67,7 @@ class MotorcycleModelWorkbook:
         power_supply_components: Optional[List[PowerSupplyComponent]] = None
         distribution: Optional[DistributionData] = None
         autodiagnosis: Optional[AutodiagnosisData] = None
-        absData: Optional[AbsData] = None
+        abs_data: Optional[AbsData] = None
 
         for sheetname in [key for key in workbook.sheetnames
                           if key in sheetnames_relationships]:
@@ -104,7 +104,7 @@ class MotorcycleModelWorkbook:
                 autodiagnosis = AutodiagnosisSheet(worksheet=workbook[sheetname]).autodiagnosis
 
             elif Sheetnames.ABS == sheetnames_relationships[sheetname]:
-                absData = AbsSheet(worksheet=workbook[sheetname]).abs
+                abs_data = AbsSheet(worksheet=workbook[sheetname]).abs_data
 
         self.motorcycle_model = MotorcycleModel(
             model_name=model_name,
@@ -116,5 +116,5 @@ class MotorcycleModelWorkbook:
             power_supply=power_supply_components,
             distribution=distribution,
             autodiagnosis=autodiagnosis,
-            absData=absData,
+            abs_data=abs_data,
         )
