@@ -1,4 +1,4 @@
-from typing import List
+from typing import List, Optional
 
 from openpyxl.cell import Cell
 from openpyxl.worksheet.worksheet import Worksheet
@@ -45,12 +45,16 @@ class SheetReader:
 
     def read_cells(
             self,
-            start_col: int,
-            end_col: int,
             start_row: int,
             end_row: int,
+            start_col: int,
+            end_col: Optional[int] = None,
     ) -> List[Cell]:
         cells: List[Cell] = list()
+
+        if end_col is None:
+            end_col = start_col
+
         end_col += 1
         end_row += 1
 
